#!/usr/bin/env python

#    Copyright (C) 2000  Bastian Kleineidam
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

__revision__ = "$Id"

import os, sys
from distutils.core import setup
from distutils.dist import Distribution
from distutils.command.install import install
from distutils.file_util import write_file
from distutils import util

class WCInstall(install):
    def run(self):
        install.run(self)
        # we have to write a configuration file because we need the
        # <install_data> directory (and other stuff like author, url, ...)
        data = []
        for d in ['purelib', 'platlib', 'lib', 'headers', 'scripts', 'data']:
            attr = 'install_'+d
            if self.root:
                val = getattr(self, attr)[len(self.root):]
            else:
                val = getattr(self, attr)
            if attr=="install_data":
                data.append('config_dir = %s' % `os.path.join(val,
                            'share/webcleaner')`)
            data.append("%s = %s" % (attr, `val`))
        from pprint import pformat
        data.append('outputs = %s' % pformat(self.get_outputs()))
        self.distribution.create_conf_file(self.install_lib, data)



class WCDistribution(Distribution):
    def __init__(self, attrs=None):
        Distribution.__init__(self, attrs=attrs)
        self.config_file = self.get_name()+"Conf.py"


    def run_commands(self):
        data = ['config_dir = %s' % `os.path.join(os.getcwd(), "config")`]
        self.create_conf_file(".", data)
        Distribution.run_commands(self)


    def create_conf_file(self, directory, data=[]):
        data.insert(0, "# this file is automatically created by setup.py")
        filename = os.path.join(directory, self.config_file)
        # add metadata
        metanames = dir(self.metadata) + \
                    ['fullname', 'contact', 'contact_email']
        for name in metanames:
              method = "get_" + name
              cmd = "%s = %s" % (name, `getattr(self.metadata, method)()`)
              data.append(cmd)
        util.execute(write_file, (filename, data),
                     "creating %s" % filename, self.verbose>=1, self.dry_run)


myname = "Bastian Kleineidam"
myemail = "calvin@users.sourceforge.net"

setup (name = "WebCleaner",
       version = "0.6",
       description = "a filtering HTTP proxy",
       author = myname,
       author_email = myemail,
       maintainer = myname,
       maintainer_email = myemail,
       url = "http://webcleaner.sourceforge.net/",
       licence = "GPL",
       packages = ['', 'webfilter'],
       scripts = ['webcleaner', 'webcleanerconf'],
       long_description =
"""WebCleaner is a filtering HTTP proxy inspired by Junkbuster,
WebWasher and FilterProxy. You can encode, decode and modify
each part of an HTTP request. WebCleaner enhances your privacy and
efficiency on the web and comes with several ready-to-use
filters to remove advertisement and unwanted HTML content,
compress documents on-the-fly, disable animated GIFs and more.
""",
       distclass = WCDistribution,
       cmdclass = {'install': WCInstall},
       data_files = [('share/webcleaner',
                     ['config/blocked.html',
                      'config/blocked.gif',
                      'webcleaner.bat',
                      'filtertest',
                      'filtertest.html',
                      'config/webcleaner.conf',
                      'config/webcleaner.dtd',
 	              'config/filter.dtd',
		      'config/adverts.zap',
		      'config/css.zap',
		      'config/erotic.zap',
		      'config/finance.zap',
		      'config/misc.zap',
		      'config/plugins.zap',
		      'config/redirects.zap',
		      'config/scripting.zap']),
		    ],
)
